Papillon main developers:

* Domenico Somma: domenico.somma@glasgow.ac.uk

Contributors:

* Emma Smith: e.smith.4@research.gla.ac.uk
  * for suggestions and Beta testing

Thanks to "riko" and python-it.org's guys for tips and suggestions.
